<?php

function connectDatabase(string $user, string $pass, string $db) {
    $unix_socket = '.mysql/mysql.sock';
    $charset = 'utf8mb4';
    $dsn = "mysql:unix_socket=$unix_socket;dbname=$db;charset=$charset";
    $pdo = new PDO($dsn, $user, $pass);
    return $pdo;
}

function closeDatabase($pdo) {
    $pdo = null;
}

function displayResults($query) {
    foreach($query->fetch(PDO::FETCH_ASSOC) as $row){
        echo $row . "\n";
    }
}

function listRows($pdo, $table) {
    $query = "SELECT * FROM ?";
    $result = $pdo->prepare($query)->execute([$table]);
    displayResults($query);
}

function findRows($pdo, string $table, string $attr, string $param) {
    $query = "SELECT * FROM ? WHERE ? = ?";
    $result = $pdo->prepare($query)->execute([$table, $attr, $param]);
    displayResults($query);
}

function createPatient($pdo, $data) {
    $query = "INSERT INTO paciente
    (nombre, apellido, fecha_de_nacimiento, documento_identificativo, tipo_documento, direccion, localidad, provincia, pais)
    VALUES (?,?,?,?,?,?,?,?,?)";
    $pdo->prepare($query)->execute([$data["nombre"], $data["apellido"], $data["fecha_de_nacimiento"],
                                  $data["documento_identificativo"], $data["tipo_documento"], $data["direccion"],
                                  $data["localidad"], $data["provincia"], $data["pais"]]);
    return "Paciente creado con éxito";
}

function editPatient($pdo, string $attr, string $param, string $id) {
    $query = "UPDATE paciente SET ? = ? WHERE documento_identificativo = ?";
    $pdo->prepare($query)->execute([$attr, $param, $id]);
    return "Paciente modificado con éxito";
}

function deletePatient($pdo, string $id) {
    $check = "SELECT * FROM informes where paciente = ?";
    $result = $pdo->prepare($check)->execute([$id]);
    if($result->columnCount() == 0){
        $statement = "DELETE FROM paciente where document_identificado = ?";
        $pdo->prepare($statement)->execute([$id]);
        return "El paciente se ha eliminado correctamente";
    }
    return "No se puede eliminar el paciente dado que tiene citas";
}

function createHoliday($pdo, $data) {
    $query = "INSERT INTO festivo (fecha_festivo, tipo_festivo, medico) VALUES (?,?,?)";
    $pdo->prepare($query)->execute([$data["fecha_festivo"], $data["tipo_festivo"], $data["medico"]]);
    return "Festivo creado con éxito";
}

function editHoliday($pdo, $attr, $param, $id) {
    $query = "UPDATE festivo SET ? = ? WHERE id = ?";
    $pdo->prepare($query)->execute([$attr, $param, $id]);
    return "Festivo modificado con éxito";
}

function deleteHoliday($pdo, str $id) {
    $statement = "DELETE FROM festivo where id = ?";
    $pdo->prepare($statement)->execute([$id]);
    return "Festivo borrado con éxito";
}

function createUser($pdo, $data) {
    $query = "INSERT INTO usuario (nombre, usuario, contraseña, rol, correo) VALUES (?,?,?,?,?)";
    $pdo->prepare($query)->execute([$data["nombre"], $data["usuario"], $data["contraseña"], $data["rol"], $data["correo"]]);
    return "Usuario creado con éxito";
}

function editUser($pdo, $attr, $param, $id) {
    $query = "UPDATE usuario SET ? = ? WHERE usuario = ?";
    $pdo->prepare($query)->execute([$attr, $param, $id]);
    return "Usuario modificado con éxito";
}

function deactivateUser($pdo, string $id) {
    editUser($pdo, "fecha_baja", "CURRENT_TIMESTAMP", $id);
    return "Usuario desactivado con éxito";
}

function listAppointments($pdo, string $doctor) {
    findRows($pdo, "cita", "medico", $doctor);
}


function displayUsers($query) {
    foreach($query->fetch(PDO::FETCH_ASSOC) as $row){
        echo $row["nombre"];
    }
}

function listUsers($pdo) {
    $query = "SELECT usuario.nombre, usuario.usuario, rol.nombre, usuario.correo FROM usuario
    INNER JOIN rol ON usuario.rol = rol.codigo";
    $result = $pdo->query($query)->fetchAll();
    return $result;
}

?>
